#ifndef NT2_INCLUDE_FUNCTIONS_REMQUO_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REMQUO_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/remquo.hpp>

#endif
